@@ -172,7 +172,7 @@ class Table:
 
     def aggregate(
         self,
-        by: str,
+        by: str = '"TOTAL"',
         query: str = "",
         aggr: Union[dict, None] = None,
         timeout: float = 30.0,
